@@ -42,21 +42,39 @@ def _default_OPSET_TO_IR_VERSION():
     return {
         1: 3, 2: 3, 3: 3, 4: 3, 5: 3, 6: 3,
         7: 3, 8: 4, 9: 4, 10: 5, 11: 6, 12: 7,
-        13: 7, 14: 7, 15: 8
+        13: 7, 14: 7, 15: 8, 16: 8, 17: 8
     }
 
 
 try:
     from onnxconverter_common.topology import OPSET_TO_IR_VERSION
-    assert OPSET_TO_IR_VERSION[15] is not None
+    assert OPSET_TO_IR_VERSION[17] is not None
 except (ImportError, KeyError):
     OPSET_TO_IR_VERSION = _default_OPSET_TO_IR_VERSION()
 
-OPSET_ML_TO_OPSET = {1: 11, 2: 15}
+OPSET_ML_TO_OPSET = {1: 11, 2: 15, 3: 17}
 
 logger = getLogger('skl2onnx')
 
 
+def get_default_opset_for_domain(domain):
+    """
+    Returns the associated for a domain given the main opset.
+    """
+    from .. import __max_supported_opset__ as main_opset
+    if domain == '':
+        return main_opset
+    if domain == 'ai.onnx.ml':
+        if main_opset >= 16:
+            return 3
+        if main_opset < 6:
+            return 1
+        return 2
+    if domain == 'ai.onnx.training':
+        return 1
+    return None
+
+
 class Variable:
     """
     Defines a variable which holds any data defined
@@ -93,8 +111,8 @@ class Variable:
                 else:
                     onnx_name = scope.get_unique_variable_name("U")
                 logger.debug(
-                    '[Var] rename raw_name=%r, onnx_name=%r into %r' % (
-                        raw_name, onnx_name0, onnx_name))
+                    '[Var] rename raw_name=%r, onnx_name=%r into %r',
+                    raw_name, onnx_name0, onnx_name)
             else:
                 raise TypeError(
                     "onnx_name must be a string not %r." % onnx_name)
@@ -138,7 +156,7 @@ class Variable:
                     raise TypeError(
                         "shape must contains integers not %r (type=%r)."
                         "" % (dim, dim.__class__))
-        logger.debug('[Var] +%s' % self)
+        logger.debug('[Var] +%s', self)
 
         # links to operators using those variables
         self.operators_outputs_ = []
@@ -150,7 +168,7 @@ class Variable:
             for k in self.type.shape:
                 if k is None:
                     continue
-                if not isinstance(k, (int, np.int64, np.intc)):
+                if not isinstance(k, (int, np.integer)):
                     raise ValueError(
                         "Unexpected type %r for shape %r."
                         "" % (type(k), self))
@@ -185,14 +203,15 @@ class Variable:
 
     def init_status(self, is_fed=None, is_root=None, is_leaf=None):
         if is_fed is not None and is_fed != self.is_fed:
-            logger.debug('[Var] update is_fed=%r for %r, parent=%r' % (
-                is_fed, self, self._parent))
+            logger.debug(
+                '[Var] update is_fed=%r for %r, parent=%r',
+                is_fed, self, self._parent)
             self._is_fed = is_fed
         if is_root is not None and is_root != self.is_root:
-            logger.debug('[Var] update is_root=%r for %r' % (is_root, self))
+            logger.debug('[Var] update is_root=%r for %r', is_root, self)
             self._is_root = is_root
         if is_leaf is not None and is_leaf != self.is_leaf:
-            logger.debug('[Var] update is_leaf=%r for %r' % (is_leaf, self))
+            logger.debug('[Var] update is_leaf=%r for %r', is_leaf, self)
             self._is_leaf = is_leaf
 
     def __setattr__(self, name, value):
@@ -212,14 +231,15 @@ class Variable:
             raise TypeError(
                 "Unexpected new type for variable %r, new_type=%r." % (
                     self, new_type))
-        logger.debug('[Var] update type for %r' % self)
+        logger.debug('[Var] update type for %r', self)
         self._type = new_type
         self._check()
 
     def set_onnx_name(self, onnx_name):
         if onnx_name != self._onnx_name:
-            logger.debug('[Var] update onnx_name, from %r to %r in %r' % (
-                self.onnx_name, onnx_name, self))
+            logger.debug(
+                '[Var] update onnx_name, from %r to %r in %r',
+                self.onnx_name, onnx_name, self)
             if self.scope is not None and not isinstance(self.scope, str):
                 self.scope.rename_onnx_name(self._onnx_name, onnx_name)
             self._onnx_name = onnx_name
@@ -229,8 +249,8 @@ class Variable:
             raise RuntimeError(
                 "This variable is already the output of operator %r. "
                 "It cannot be the output of %r." % (self._parent, operator))
-        logger.debug('[Var] set parent for %r, parent=%r' % (
-            self, operator))
+        logger.debug(
+            '[Var] set parent for %r, parent=%r', self, operator)
         self._parent = operator
 
     def get_first_dimension(self):
@@ -398,7 +418,7 @@ class Operator:
             if self.kind == 'Out':
                 v.set_parent(self.parent)
             super(Operator.OperatorList, self).append(v)
-            logger.debug("[Op] add %s %r to %r" % (self.kind, v, self.parent))
+            logger.debug("[Op] add %s %r to %r", self.kind, v, self.parent)
             if self.kind == 'In':
                 v.add_operator(self.parent, False)
             elif self.kind == "Out":
@@ -427,8 +447,9 @@ class Operator:
             if not isinstance(v, Variable):
                 raise TypeError(
                     "Value v must be a Variable not %r." % type(v))
-            logger.debug("[Op] %s-change element %d from %r to %r in %r" % (
-                self.kind, i, self[i], v, self.parent))
+            logger.debug(
+                "[Op] %s-change element %d from %r to %r in %r",
+                self.kind, i, self[i], v, self.parent)
             list.__setitem__(self, i, v)
 
         def to_string(self):
@@ -472,7 +493,7 @@ class Operator:
         self._is_evaluated = None
         self.target_opset = target_opset
         self.scope_inst = scope_inst
-        logger.debug('[Op] +%r' % self)
+        logger.debug('[Op] +%r', self)
 
     def new_raw_operator(self, raw_operator, alias):
         """
@@ -529,8 +550,9 @@ class Operator:
 
     def init_status(self, is_evaluated=None):
         if is_evaluated is not None and is_evaluated != self.is_evaluated:
-            logger.debug('[Op] update is_evaluated=%r for %r' % (
-                is_evaluated, self))
+            logger.debug(
+                '[Op] update is_evaluated=%r for %r',
+                is_evaluated, self)
             self._is_evaluated = is_evaluated
 
     @property
@@ -577,13 +599,14 @@ class Operator:
             raise MissingShapeCalculator(
                 "Unexpected shape calculator for alias '{}' "
                 "and type '{}'.".format(self.type, type(self.raw_operator)))
-        logger.debug("[Shape-a] %r fed %r - %r" % (
-            self,
+        logger.debug(
+            "[Shape-a] %r fed %r - %r", self,
             "".join(str(i.is_fed) for i in self.inputs),
-            "".join(str(i.is_fed) for i in self.outputs)))
+            "".join(str(i.is_fed) for i in self.outputs))
         shape_calc(self)
-        logger.debug("[Shape-b] %r inputs=%r - outputs=%r" % (
-            self, self.inputs, self.outputs))
+        logger.debug(
+            "[Shape-b] %r inputs=%r - outputs=%r",
+            self, self.inputs, self.outputs)
 
 
 class Scope:
@@ -735,6 +758,28 @@ class Scope:
 
         self.variables[var.onnx_name] = var
 
+    def declare_existing_subgraph_name(self, graph_proto):
+        """
+        Declare all name from a subgraph in order to avoid being picked twice.
+        """
+        output_name = {o.name for o in graph_proto.output}
+        for node in graph_proto.node:
+            for name in node.output:
+                if name in output_name:
+                    continue
+                if self.has_variable_name(name):
+                    raise NameError(
+                        "Result name %r is already taken (outputs=%r) "
+                        "(node=%r)." % (
+                            name, output_name, node))
+                self.onnx_variable_names.add(name)
+            if node.name in self.onnx_operator_names:
+                raise NameError(
+                    "Operator name %r is already taken "
+                    "(node=%r)." % (
+                        node.name, node))
+            self.onnx_operator_names.add(node.name)
+
     def rename_onnx_name(self, old_name, new_name):
         if new_name in self.variables:
             raise RuntimeError(
@@ -743,8 +788,9 @@ class Scope:
         if old_name not in self.variables:
             raise RuntimeError(
                 "Unable to find name %r in variables." % old_name)
-        logger.debug('[Scope] update onnx_name, from %r to %r' % (
-            old_name, new_name))
+        logger.debug(
+            '[Scope] update onnx_name, from %r to %r',
+            old_name, new_name)
         self.variables[new_name] = self.variables[old_name]
         del self.variables[old_name]
 
@@ -839,8 +885,9 @@ class Scope:
         """
         for v in self.operators.values():
             if id(v.raw_operator) == id(op1):
-                logger.debug('[Scope] replace %d by %d in %r.' % (
-                    id(v.raw_operator), id(op1), v))
+                logger.debug(
+                    '[Scope] replace %d by %d in %r.',
+                    id(v.raw_operator), id(op1), v)
                 v.raw_operator = op2
                 v.type = alias
 
@@ -929,7 +976,7 @@ class Topology:
 
         # Make the seed meet C-style naming convention
         # Only alphabets and numbers are allowed
-        seed = re.sub('[^0-9a-zA-Z]', '_', seed)
+        seed = re.sub('[^\\w+]', '_', seed)
         # The first symbol cannot be a number
         if re.match('^[0-9]', seed):
             seed = '_' + seed
@@ -1008,12 +1055,12 @@ class Topology:
         container.validate_options(operator)
         if verbose > 0:
             print("[call_converter] call converter for %r." % operator.type)
-        logger.debug("[Conv] call %r fed %r - %r" % (
-            operator,
+        logger.debug(
+            "[Conv] call %r fed %r - %r", operator,
             "".join(str(i.is_fed) for i in operator.inputs),
-            "".join(str(i.is_fed) for i in operator.outputs)))
+            "".join(str(i.is_fed) for i in operator.outputs))
         conv(self.scopes[0], operator, container)
-        logger.debug("[Conv] end - %r" % operator)
+        logger.debug("[Conv] end - %r", operator)
 
     def call_shape_calculator(self, operator):
         "Calls shape_calculator for operator *operator*."
@@ -1033,14 +1080,14 @@ class Topology:
             shape_calc = None
 
         if shape_calc is not None:
-            logger.debug("[Shape1] %r fed %r - %r (source=%r)" % (
-                operator,
+            logger.debug(
+                "[Shape1] %r fed %r - %r (source=%r)", operator,
                 ",".join(str(i.is_fed) for i in operator.inputs),
                 ",".join(str(i.is_fed) for i in operator.outputs),
-                source))
+                source)
             shape_calc(operator)
         else:
-            logger.debug('[Shape2] call infer_types for %r' % operator)
+            logger.debug('[Shape2] call infer_types for %r', operator)
             operator.infer_types()
 
     def _initialize_graph_status_for_traversing(self):
@@ -1061,11 +1108,14 @@ class Topology:
         for operator in self.unordered_operator_iterator():
             operator.init_status(is_evaluated=False)
 
-    def _propagate_status(self, operator, container, fed_variables):
+    def _propagate_status(self, operator, container, fed_variables,
+                          verbose=0):
         """
         Propagates status *is_fed* based on output variable
         and node added in the container.
         """
+        if verbose > 1:
+            print("[_propagate_status] after op=%r" % operator)
         vars = {}
         for node in container.nodes:
             for i in node.input:
@@ -1073,8 +1123,10 @@ class Topology:
                     vars[i] = []
                 vars[i].append(node)
 
-        stack = [v.onnx_name for v in operator.outputs if v.is_fed]
-        stack.extend(v.onnx_name for v in operator.inputs if v.is_fed)
+        if verbose > 1:
+            print("[_propagate_status] newly fed=%r" % list(
+                v.onnx_name for v in operator.outputs if v.is_fed))
+        stack = list(fed_variables)
         scope = self.scopes[0]
         while len(stack) > 0:
             nodes = {}
@@ -1088,11 +1140,15 @@ class Topology:
                 if all(fed_variables.get(n, False) for n in node.input):
                     for o in node.output:
                         if o not in fed_variables:
+                            if verbose > 1:
+                                print("[_propagate_status] add=%r" % o)
                             fed_variables[o] = o
                             stack.append(o)
                             if o in scope.variables:
                                 var = scope.variables[o]
                                 var.init_status(is_fed=True)
+                                if verbose > 1:
+                                    print("[_propagate_status] fed=%r" % var)
 
     def convert_operators(self, container=None, verbose=0):
         """
@@ -1210,7 +1266,9 @@ class Topology:
                     fed_variables.update(
                         {i.name: i for i in container.initializers
                          if i.name not in fed_variables})
-                    self._propagate_status(operator, container, fed_variables)
+                    self._propagate_status(operator, container, fed_variables,
+                                           verbose=verbose)
+
                     # unfed some variables (it happens when a node
                     # shares an output with another node)
                     rem = []
@@ -1291,8 +1349,8 @@ class Topology:
                     container.swap_names(old_name, new_name)
                 except NotImplementedError as e:
                     logger.debug(
-                        '[Topo] unable to swap %r and %r (%r).' % (
-                            old_name, new_name, e))
+                        '[Topo] unable to swap %r and %r (%r).',
+                        old_name, new_name, e)
                     continue
 
                 for v in self.unordered_variable_iterator():
@@ -1476,7 +1534,16 @@ def _update_domain_version(container, onnx_model, verbose=0):
             print('[_update_domain_version] +opset %d: name=%r, version=%s' % (
                 i, op_domain, op_version))
         op_set.domain = op_domain
+        if op_set != '':
+            max_supported = get_default_opset_for_domain(op_domain)
+            if max_supported is not None and max_supported < op_version:
+                raise RuntimeError(
+                    "The model is using version %d of domain %r not supported "
+                    "yet by this library. You need to specify "
+                    "target_opset={%r: %r}." % (
+                        op_version, op_domain, op_domain, max_supported))
         op_set.version = op_version
+
         i += 1
         if container.target_opset_any_domain(op_domain) < op_version:
             raise RuntimeError(
