@@ -14,6 +14,15 @@ from onnxconverter_common.utils import check_input_and_output_numbers  # noqa
 from onnxconverter_common.utils import check_input_and_output_types  # noqa
 from .data_types import TensorType
 
+_unique_index = {'subgraph': 0}
+
+
+def get_unique_subgraph():
+    "Returns a unique identifier integer for subgraph."
+    global _unique_index
+    _unique_index['subgraph'] += 1
+    return _unique_index['subgraph']
+
 
 def get_producer():
     """
@@ -103,7 +112,10 @@ def get_column_index(i, inputs):
             "Unable to find column name %r among names %r. "
             "Make sure the input names specified with parameter "
             "initial_types fits the column names specified in the "
-            "pipeline to convert." % (i, [n.onnx_name for n in inputs]))
+            "pipeline to convert. This may happen because a "
+            "ColumnTransformer follows a transformer without "
+            "any mapped converter in a pipeline." % (
+                i, [n.onnx_name for n in inputs]))
 
 
 def get_column_indices(indices, inputs, multiple):
