@@ -12,6 +12,7 @@ from ..common.data_types import (
     guess_numpy_type, Int64TensorType, guess_proto_type)
 from ..common._registration import register_converter
 from .._supported_operators import sklearn_operator_name_map
+from sklearn.ensemble import RandomForestClassifier
 
 
 def _handle_zeros(scope, container, concatenated_prob_name,
@@ -74,10 +75,22 @@ def _transform_sigmoid(scope, container, model, df_col_name, k, proto_type):
     if proto_type2 not in (TensorProto.FLOAT, TensorProto.DOUBLE):
         proto_type2 = TensorProto.FLOAT
 
+    if hasattr(model, 'calibrators_'):
+        # scikit-learn<1.1
+        calibrators = model.calibrators_
+    elif hasattr(model, 'calibrators'):
+        # scikit-learn>=1.1
+        calibrators = model.calibrators
+    else:
+        raise AttributeError(
+            "Unable to find attribute calibrators_ or "
+            "calibrators, check the model was trained, "
+            "type=%r." % type(model))
+
     container.add_initializer(a_name, proto_type2,
-                              [], [model.calibrators_[k].a_])
+                              [], [calibrators[k].a_])
     container.add_initializer(b_name, proto_type2,
-                              [], [model.calibrators_[k].b_])
+                              [], [calibrators[k].b_])
     container.add_initializer(unity_name, proto_type2, [], [1])
 
     apply_mul(scope, [a_name, df_col_name], a_df_prod_name, container,
@@ -99,14 +112,24 @@ def _transform_isotonic(scope, container, model, T, k, dtype, proto_type):
     ArrayFeatureExtractor can only extract based on the last axis,
     so we can't fetch different columns for different rows.
     """
-    if model.calibrators_[k].out_of_bounds == 'clip':
+    if hasattr(model, 'calibrators_'):
+        # scikit-learn<1.1
+        calibrators = model.calibrators_
+    elif hasattr(model, 'calibrators'):
+        # scikit-learn>=1.1
+        calibrators = model.calibrators
+    else:
+        raise AttributeError(
+            "Unable to find attribute calibrators_ or "
+            "calibrators, check the model was trained, "
+            "type=%r." % type(model))
+
+    if calibrators[k].out_of_bounds == 'clip':
         clipped_df_name = scope.get_unique_variable_name('clipped_df')
         apply_clip(scope, T, clipped_df_name, container,
                    operator_name=scope.get_unique_operator_name('Clip'),
-                   max=np.array(model.calibrators_[k].X_max_,
-                                dtype=dtype),
-                   min=np.array(model.calibrators_[k].X_min_,
-                                dtype=dtype))
+                   max=np.array(calibrators[k].X_max_, dtype=dtype),
+                   min=np.array(calibrators[k].X_min_, dtype=dtype))
         T = clipped_df_name
 
     reshaped_df_name = scope.get_unique_variable_name('reshaped_df')
@@ -119,18 +142,18 @@ def _transform_isotonic(scope, container, model, T, k, dtype, proto_type):
         'nearest_x_index')
     nearest_y_name = scope.get_unique_variable_name('nearest_y')
 
-    if hasattr(model.calibrators_[k], '_X_'):
+    if hasattr(calibrators[k], '_X_'):
         atX, atY = '_X_', '_y_'
-    elif hasattr(model.calibrators_[k], '_necessary_X_'):
+    elif hasattr(calibrators[k], '_necessary_X_'):
         atX, atY = '_necessary_X_', '_necessary_y_'
-    elif hasattr(model.calibrators_[k], 'X_thresholds_'):
+    elif hasattr(calibrators[k], 'X_thresholds_'):
         atX, atY = 'X_thresholds_', 'y_thresholds_'
     else:
         raise AttributeError(
             "Unable to find attribute '_X_' or '_necessary_X_' "
             "for type {}\n{}."
-            "".format(type(model.calibrators_[k]),
-                      pprint.pformat(dir(model.calibrators_[k]))))
+            "".format(type(calibrators[k]),
+                      pprint.pformat(dir(calibrators[k]))))
 
     proto_type2 = proto_type
     if proto_type2 not in (TensorProto.FLOAT, TensorProto.DOUBLE):
@@ -138,12 +161,12 @@ def _transform_isotonic(scope, container, model, T, k, dtype, proto_type):
 
     container.add_initializer(
         calibrator_x_name, proto_type2,
-        [len(getattr(model.calibrators_[k], atX))],
-        getattr(model.calibrators_[k], atX))
+        [len(getattr(calibrators[k], atX))],
+        getattr(calibrators[k], atX))
     container.add_initializer(
         calibrator_y_name, proto_type2,
-        [len(getattr(model.calibrators_[k], atY))],
-        getattr(model.calibrators_[k], atY))
+        [len(getattr(calibrators[k], atY))],
+        getattr(calibrators[k], atY))
 
     apply_reshape(scope, T, reshaped_df_name, container,
                   desired_shape=(-1, 1))
@@ -256,6 +279,8 @@ def convert_calibrated_classifier_base_estimator(scope, operator, container,
     #                           |                        |
     #                           V                        |
     #                        class_prob_tensor [M, C] <--'
+    model_proba = {RandomForestClassifier}
+
     if scope.get_options(operator.raw_operator, dict(nocl=False))['nocl']:
         raise RuntimeError(
             "Option 'nocl' is not implemented for operator '{}'.".format(
@@ -275,7 +300,8 @@ def convert_calibrated_classifier_base_estimator(scope, operator, container,
     prob_name = [None] * n_classes
 
     this_operator = scope.declare_local_operator(op_type, base_model)
-    if container.has_options(base_model, 'raw_scores'):
+    if (container.has_options(base_model, 'raw_scores') and
+            not type(base_model) in model_proba):
         container.add_options(id(base_model), {'raw_scores': True})
         scope.add_options(id(base_model), {'raw_scores': True})
     this_operator.inputs = operator.inputs
@@ -473,4 +499,5 @@ def convert_sklearn_calibrated_classifier_cv(
 register_converter('SklearnCalibratedClassifierCV',
                    convert_sklearn_calibrated_classifier_cv,
                    options={'zipmap': [True, False, 'columns'],
+                            'output_class_labels': [False, True],
                             'nocl': [True, False]})
