@@ -385,12 +385,9 @@ def convert_nearest_neighbors_regressor(scope: Scope, operator: Operator,
                 shape = OnnxShape(res, op_version=opv)
                 norm = OnnxReshapeApi13(norm, shape, op_version=opv)
                 norm.set_onnx_name_prefix('normr')
-            if opv >= 12:
-                res = OnnxDiv(res, norm, op_version=opv, output_names=out)
-            else:
-                res = OnnxDiv(res, norm, op_version=opv)
-                res = OnnxReshapeApi13(res, np.array([-1, 1], dtype=np.int64),
-                                       output_names=out, op_version=opv)
+            res = OnnxDiv(res, norm, op_version=opv)
+            res = OnnxReshapeApi13(res, np.array([-1, 1], dtype=np.int64),
+                                   output_names=out, op_version=opv)
     else:
         if (hasattr(operator.raw_operator, '_y') and
                 len(np.squeeze(operator.raw_operator._y).shape) == 1):
@@ -754,12 +751,14 @@ register_converter(
     options={'zipmap': [True, False, 'columns'],
              'nocl': [True, False],
              'raw_scores': [True, False],
+             'output_class_labels': [False, True],
              'optim': [None, 'cdist']})
 register_converter(
     'SklearnRadiusNeighborsClassifier', convert_nearest_neighbors_classifier,
     options={'zipmap': [True, False, 'columns'],
              'nocl': [True, False],
              'raw_scores': [True, False],
+             'output_class_labels': [False, True],
              'optim': [None, 'cdist']})
 register_converter(
     'SklearnKNeighborsRegressor', convert_nearest_neighbors_regressor,
