@@ -1,10 +1,8 @@
 # SPDX-License-Identifier: Apache-2.0
 
 import unittest
-from distutils.version import StrictVersion
 import numpy as np
 from numpy.testing import assert_almost_equal
-import onnx
 from onnx.defs import onnx_opset_version
 from onnxruntime import InferenceSession
 try:
@@ -25,8 +23,7 @@ from test_utils import fit_regression_model, TARGET_OPSET
 
 class TestOnnxOperatorsCascade(unittest.TestCase):
 
-    @unittest.skipIf(StrictVersion(onnx.__version__) < StrictVersion("1.4.0"),
-                     reason="not available")
+    @unittest.skipIf(TARGET_OPSET < 9, reason="not available")
     def test_cascade_add(self):
 
         def generate_onnx_graph(dim, nbnode, input_name='X1', opv=None):
@@ -97,8 +94,7 @@ class TestOnnxOperatorsCascade(unittest.TestCase):
             res = res_out[0]
             assert res.shape[1] == dim
 
-    @unittest.skipIf(StrictVersion(onnx.__version__) < StrictVersion("1.4.0"),
-                     reason="not available")
+    @unittest.skipIf(TARGET_OPSET < 9, reason="not available")
     def test_cascade_scaler(self):
 
         def generate_onnx_graph(dim, nbnode, input_name='X1', opv=1):
@@ -153,8 +149,7 @@ class TestOnnxOperatorsCascade(unittest.TestCase):
         res = res_out[0]
         assert res.shape[1] == dim
 
-    @unittest.skipIf(StrictVersion(onnx.__version__) < StrictVersion("1.4.0"),
-                     reason="not available")
+    @unittest.skipIf(TARGET_OPSET < 9, reason="not available")
     def test_scaler_converted(self):
         st = StandardScaler()
         X = np.array([[0, 1.5], [6.1, 2.3]])
@@ -205,8 +200,7 @@ class TestOnnxOperatorsCascade(unittest.TestCase):
                 res = res_out[0]
                 assert_almost_equal(exp, res)
 
-    @unittest.skipIf(StrictVersion(onnx.__version__) < StrictVersion("1.4.0"),
-                     reason="not available")
+    @unittest.skipIf(TARGET_OPSET < 9, reason="not available")
     def test_model_mlp_regressor_default(self):
         model, X_test = fit_regression_model(
             MLPRegressor(random_state=42))
@@ -214,35 +208,36 @@ class TestOnnxOperatorsCascade(unittest.TestCase):
         for opv in (1, 2, 7, 8, 9, 10, 11, 12, 13, onnx_opset_version()):
             if opv is not None and opv > TARGET_OPSET:
                 continue
-            try:
-                onx = convert_sklearn(
-                    model, "scikit-learn MLPRegressor",
-                    [("input", FloatTensorType([None, X_test.shape[1]]))],
-                    target_opset=opv)
-            except RuntimeError as e:
-                if ("is higher than the number of the "
-                        "installed onnx package") in str(e):
-                    continue
-                raise e
-            as_string = onx.SerializeToString()
-            try:
-                ort = InferenceSession(as_string)
-            except (RuntimeError, InvalidGraph, Fail) as e:
-                if opv in (None, 1, 2):
-                    continue
-                if opv >= onnx_opset_version():
-                    continue
-                if ("No suitable kernel definition found for "
-                        "op Cast(9)") in str(e):
-                    # too old onnxruntime
-                    continue
-                raise AssertionError(
-                    "Unable to load opv={}\n---\n{}\n---".format(
-                        opv, onx)) from e
-            res_out = ort.run(None, {'input': X_test})
-            assert len(res_out) == 1
-            res = res_out[0]
-            assert_almost_equal(exp.ravel(), res.ravel(), decimal=4)
+            with self.subTest(opv=opv):
+                try:
+                    onx = convert_sklearn(
+                        model, "scikit-learn MLPRegressor",
+                        [("input", FloatTensorType([None, X_test.shape[1]]))],
+                        target_opset=opv)
+                except RuntimeError as e:
+                    if ("is higher than the number of the "
+                            "installed onnx package") in str(e):
+                        continue
+                    raise e
+                as_string = onx.SerializeToString()
+                try:
+                    ort = InferenceSession(as_string)
+                except (RuntimeError, InvalidGraph, Fail) as e:
+                    if opv in (None, 1, 2):
+                        continue
+                    if opv >= onnx_opset_version():
+                        continue
+                    if ("No suitable kernel definition found for "
+                            "op Cast(9)") in str(e):
+                        # too old onnxruntime
+                        continue
+                    raise AssertionError(
+                        "Unable to load opv={}\n---\n{}\n---".format(
+                            opv, onx)) from e
+                res_out = ort.run(None, {'input': X_test})
+                assert len(res_out) == 1
+                res = res_out[0]
+                assert_almost_equal(exp.ravel(), res.ravel(), decimal=4)
 
 
 if __name__ == "__main__":
