@@ -1,5 +1,5 @@
 import unittest
-from distutils.version import StrictVersion
+import packaging.version as pv
 import numpy as np
 from sklearn.cluster import KMeans
 from sklearn.datasets import load_diabetes
@@ -33,6 +33,7 @@ warnings_to_skip = (
 
 ORT_VERSION = "1.7.0"
 OPSET_VERSION = 11
+ort_version = ".".join(ort_version.split('.')[:2])
 
 
 class TestSklearnDoubleTensorTypeTransformer(unittest.TestCase):
@@ -67,7 +68,7 @@ class TestSklearnDoubleTensorTypeTransformer(unittest.TestCase):
                     basename="Sklearn{}Double".format(name))
 
     @unittest.skipIf(
-        StrictVersion(ort_version) < StrictVersion("0.5.0"),
+        pv.Version(ort_version) < pv.Version("0.5.0"),
         reason="onnxruntime misses operator for double")
     @ignore_warnings(category=warnings_to_skip)
     def test_scaler_64(self):
@@ -111,7 +112,7 @@ class TestSklearnDoubleTensorTypeTransformer(unittest.TestCase):
         TARGET_OPSET < OPSET_VERSION,
         reason="onnxruntime misses Gemm for double")
     @unittest.skipIf(
-        StrictVersion(ort_version) < StrictVersion(ORT_VERSION),
+        pv.Version(ort_version) < pv.Version(ORT_VERSION),
         reason="onnxruntime misses Gemm for double")
     @ignore_warnings(category=warnings_to_skip)
     def test_model_gaussian_mixture_binary_classification(self):
@@ -141,7 +142,7 @@ class TestSklearnDoubleTensorTypeTransformer(unittest.TestCase):
         TARGET_OPSET < OPSET_VERSION,
         reason="onnx misses Gemm for double")
     @unittest.skipIf(
-        StrictVersion(ort_version) < StrictVersion(ORT_VERSION),
+        pv.Version(ort_version) < pv.Version(ORT_VERSION),
         reason="onnxruntime misses Gemm for double")
     @ignore_warnings(category=warnings_to_skip)
     def test_model_bayesian_mixture_binary_classification(self):
@@ -164,7 +165,7 @@ class TestSklearnDoubleTensorTypeTransformer(unittest.TestCase):
         TARGET_OPSET < OPSET_VERSION,
         reason="onnx misses Gemm for double")
     @unittest.skipIf(
-        StrictVersion(ort_version) < StrictVersion(ORT_VERSION),
+        pv.Version(ort_version) < pv.Version(ORT_VERSION),
         reason="onnxruntime misses Gemm for double")
     @ignore_warnings(category=warnings_to_skip)
     def test_model_gaussian_mixture_multiclass(self):
@@ -184,7 +185,7 @@ class TestSklearnDoubleTensorTypeTransformer(unittest.TestCase):
         TARGET_OPSET < OPSET_VERSION,
         reason="onnx misses Gemm for double")
     @unittest.skipIf(
-        StrictVersion(ort_version) < StrictVersion(ORT_VERSION),
+        pv.Version(ort_version) < pv.Version(ORT_VERSION),
         reason="onnxruntime misses Gemm for double")
     @ignore_warnings(category=warnings_to_skip)
     def test_gaussian_mixture_comp2(self):
@@ -203,7 +204,7 @@ class TestSklearnDoubleTensorTypeTransformer(unittest.TestCase):
         self._test_score(model, X, TARGET_OPSET)
 
     @unittest.skipIf(
-        StrictVersion(ort_version) < StrictVersion(ORT_VERSION),
+        pv.Version(ort_version) < pv.Version(ORT_VERSION),
         reason="onnxruntime misses Gemm for double")
     @unittest.skipIf(
         TARGET_OPSET < OPSET_VERSION,
@@ -228,7 +229,7 @@ class TestSklearnDoubleTensorTypeTransformer(unittest.TestCase):
         TARGET_OPSET < OPSET_VERSION,
         reason="onnxruntime misses Gemm for double")
     @unittest.skipIf(
-        StrictVersion(ort_version) < StrictVersion(ORT_VERSION),
+        pv.Version(ort_version) < pv.Version(ORT_VERSION),
         reason="onnxruntime misses Gemm for double")
     @ignore_warnings(category=warnings_to_skip)
     def test_gaussian_mixture_tied(self):
@@ -250,7 +251,7 @@ class TestSklearnDoubleTensorTypeTransformer(unittest.TestCase):
         TARGET_OPSET < OPSET_VERSION,
         reason="onnx misses Gemm for double")
     @unittest.skipIf(
-        StrictVersion(ort_version) < StrictVersion(ORT_VERSION),
+        pv.Version(ort_version) < pv.Version(ORT_VERSION),
         reason="onnxruntime misses Gemm for double")
     @ignore_warnings(category=warnings_to_skip)
     def test_gaussian_mixture_diag(self):
@@ -273,7 +274,7 @@ class TestSklearnDoubleTensorTypeTransformer(unittest.TestCase):
         TARGET_OPSET < OPSET_VERSION,
         reason="onnx misses Gemm for double")
     @unittest.skipIf(
-        StrictVersion(ort_version) < StrictVersion(ORT_VERSION),
+        pv.Version(ort_version) < pv.Version(ORT_VERSION),
         reason="onnxruntime misses Gemm for double")
     @ignore_warnings(category=warnings_to_skip)
     def test_gaussian_mixture_spherical(self):
@@ -295,7 +296,7 @@ class TestSklearnDoubleTensorTypeTransformer(unittest.TestCase):
         TARGET_OPSET < OPSET_VERSION,
         reason="onnx misses Gemm for double")
     @unittest.skipIf(
-        StrictVersion(ort_version) < StrictVersion(ORT_VERSION),
+        pv.Version(ort_version) < pv.Version(ORT_VERSION),
         reason="onnxruntime misses Gemm for double")
     @ignore_warnings(category=warnings_to_skip)
     def _test_gaussian_mixture_full_black_op(self):
@@ -319,7 +320,7 @@ class TestSklearnDoubleTensorTypeTransformer(unittest.TestCase):
         self._test_score(model, X, TARGET_OPSET)
 
     @unittest.skipIf(
-        StrictVersion(ort_version) < StrictVersion(ORT_VERSION),
+        pv.Version(ort_version) < pv.Version(ORT_VERSION),
         reason="onnxruntime misses Gemm for double")
     @unittest.skipIf(TARGET_OPSET < 11,
                      reason="OnnxEqual does not support float")
@@ -347,7 +348,7 @@ class TestSklearnDoubleTensorTypeTransformer(unittest.TestCase):
         self._test_score(model, X, TARGET_OPSET)
 
     @unittest.skipIf(
-        StrictVersion(ort_version) < StrictVersion(ORT_VERSION),
+        pv.Version(ort_version) < pv.Version(ORT_VERSION),
         reason="onnxruntime misses Gemm for double")
     @unittest.skipIf(TARGET_OPSET < 11,
                      reason="OnnxEqual does not support float")
@@ -385,7 +386,7 @@ class TestSklearnDoubleTensorTypeTransformer(unittest.TestCase):
             decimal=2)
 
     @unittest.skipIf(
-        StrictVersion(ort_version) < StrictVersion(ORT_VERSION),
+        pv.Version(ort_version) < pv.Version(ORT_VERSION),
         reason="onnxruntime misses Where for double")
     @ignore_warnings(category=warnings_to_skip)
     def test_binarizer(self):
@@ -393,6 +394,7 @@ class TestSklearnDoubleTensorTypeTransformer(unittest.TestCase):
                          [2., 0., 0.],
                          [0., 1., -1.]], dtype=np.float64)
         model = Binarizer(threshold=0.5)
+        model.fit(data)
         model_onnx = convert_sklearn(
             model, "scikit-learn binarizer",
             [("input", DoubleTensorType(data.shape))],
@@ -406,7 +408,7 @@ class TestSklearnDoubleTensorTypeTransformer(unittest.TestCase):
         TARGET_OPSET < OPSET_VERSION,
         reason="onnx misses Gemm for double")
     @unittest.skipIf(
-        StrictVersion(ort_version) < StrictVersion(ORT_VERSION),
+        pv.Version(ort_version) < pv.Version(ORT_VERSION),
         reason="onnxruntime misses Gemm for double")
     @ignore_warnings(category=warnings_to_skip)
     def test_kmeans_clustering(self):
@@ -427,7 +429,7 @@ class TestSklearnDoubleTensorTypeTransformer(unittest.TestCase):
         TARGET_OPSET < OPSET_VERSION,
         reason="onnx misses ArgMin for double")
     @unittest.skipIf(
-        StrictVersion(ort_version) < StrictVersion(ORT_VERSION),
+        pv.Version(ort_version) < pv.Version(ORT_VERSION),
         reason="onnxruntime misses Gemm for double")
     @ignore_warnings(category=warnings_to_skip)
     def test_kmeans_clustering_nogemm(self):
@@ -446,7 +448,7 @@ class TestSklearnDoubleTensorTypeTransformer(unittest.TestCase):
             basename="SklearnKMeansDoubleNoGemm-Dec4")
 
     @unittest.skipIf(
-        StrictVersion(ort_version) < StrictVersion("0.5.0"),
+        pv.Version(ort_version) < pv.Version("0.5.0"),
         reason="onnxruntime misses Gemm for double")
     @ignore_warnings(category=warnings_to_skip)
     def test_pca_default(self):
@@ -458,7 +460,7 @@ class TestSklearnDoubleTensorTypeTransformer(unittest.TestCase):
             model.fit(X_train)
             return model, X_test.astype(np.float64)
 
-        model, X_test = _fit_model_pca(PCA(random_state=42))
+        model, X_test = _fit_model_pca(PCA(random_state=42, n_components=2))
         model_onnx = convert_sklearn(
             model, initial_types=[
                 ("input", DoubleTensorType([None, X_test.shape[1]]))],
