@@ -1,9 +1,7 @@
 # SPDX-License-Identifier: Apache-2.0
 
-from distutils.version import StrictVersion
 import unittest
 import numpy as np
-import onnx
 from sklearn.naive_bayes import (
     BernoulliNB,
     GaussianNB,
@@ -25,7 +23,6 @@ from skl2onnx.common.data_types import (
     FloatTensorType,
     Int64TensorType,
 )
-from skl2onnx.common.data_types import onnx_built_with_ml
 from test_utils import (
     dump_data_and_model,
     fit_classification_model,
@@ -35,8 +32,6 @@ from test_utils import (
 
 class TestNaiveBayesConverter(unittest.TestCase):
 
-    @unittest.skipIf(not onnx_built_with_ml(),
-                     reason="Requires ONNX-ML extension.")
     def test_model_multinomial_nb_binary_classification(self):
         model, X = fit_classification_model(
             MultinomialNB(), 2, pos_features=True)
@@ -51,17 +46,9 @@ class TestNaiveBayesConverter(unittest.TestCase):
             X.astype(np.float32),
             model,
             model_onnx,
-            basename="SklearnBinMultinomialNB-Dec4",
-            allow_failure="StrictVersion(onnxruntime.__version__)"
-            "<= StrictVersion('0.2.1')",
-        )
+            basename="SklearnBinMultinomialNB-Dec4")
 
-    @unittest.skipIf(
-        StrictVersion(onnx.__version__) <= StrictVersion("1.3"),
-        reason="Requires opset 9.",
-    )
-    @unittest.skipIf(not onnx_built_with_ml(),
-                     reason="Requires ONNX-ML extension.")
+    @unittest.skipIf(TARGET_OPSET < 9, reason="not available")
     def test_model_bernoulli_nb_binary_classification(self):
         model, X = fit_classification_model(
             BernoulliNB(), 2)
@@ -76,13 +63,8 @@ class TestNaiveBayesConverter(unittest.TestCase):
             X,
             model,
             model_onnx,
-            basename="SklearnBinBernoulliNB",
-            allow_failure="StrictVersion(onnxruntime.__version__)"
-            "<= StrictVersion('0.2.1')",
-        )
+            basename="SklearnBinBernoulliNB")
 
-    @unittest.skipIf(not onnx_built_with_ml(),
-                     reason="Requires ONNX-ML extension.")
     def test_model_multinomial_nb_multiclass(self):
         model, X = fit_classification_model(
             MultinomialNB(), 5, pos_features=True)
@@ -97,13 +79,8 @@ class TestNaiveBayesConverter(unittest.TestCase):
             X,
             model,
             model_onnx,
-            basename="SklearnMclMultinomialNB-Dec4",
-            allow_failure="StrictVersion(onnxruntime.__version__)"
-            "<= StrictVersion('0.2.1')",
-        )
+            basename="SklearnMclMultinomialNB-Dec4")
 
-    @unittest.skipIf(not onnx_built_with_ml(),
-                     reason="Requires ONNX-ML extension.")
     def test_model_multinomial_nb_multiclass_params(self):
         model, X = fit_classification_model(
             MultinomialNB(alpha=0.5, fit_prior=False), 5, pos_features=True)
@@ -123,17 +100,9 @@ class TestNaiveBayesConverter(unittest.TestCase):
             X[ind],
             model,
             model_onnx,
-            basename="SklearnMclMultinomialNBParams-Dec4",
-            allow_failure="StrictVersion(onnxruntime.__version__)"
-            "<= StrictVersion('0.2.1')",
-        )
+            basename="SklearnMclMultinomialNBParams-Dec4")
 
-    @unittest.skipIf(
-        StrictVersion(onnx.__version__) <= StrictVersion("1.3"),
-        reason="Requires opset 9.",
-    )
-    @unittest.skipIf(not onnx_built_with_ml(),
-                     reason="Requires ONNX-ML extension.")
+    @unittest.skipIf(TARGET_OPSET < 9, reason="not available")
     def test_model_bernoulli_nb_multiclass(self):
         model, X = fit_classification_model(
             BernoulliNB(), 4)
@@ -148,17 +117,9 @@ class TestNaiveBayesConverter(unittest.TestCase):
             X,
             model,
             model_onnx,
-            basename="SklearnMclBernoulliNB",
-            allow_failure="StrictVersion(onnxruntime.__version__)"
-            "<= StrictVersion('0.2.1')",
-        )
+            basename="SklearnMclBernoulliNB")
 
-    @unittest.skipIf(
-        StrictVersion(onnx.__version__) <= StrictVersion("1.3"),
-        reason="Requires opset 9.",
-    )
-    @unittest.skipIf(not onnx_built_with_ml(),
-                     reason="Requires ONNX-ML extension.")
+    @unittest.skipIf(TARGET_OPSET < 9, reason="not available")
     def test_model_bernoulli_nb_multiclass_params(self):
         model, X = fit_classification_model(
             BernoulliNB(alpha=0, binarize=1.0, fit_prior=False), 4)
@@ -173,13 +134,8 @@ class TestNaiveBayesConverter(unittest.TestCase):
             X,
             model,
             model_onnx,
-            basename="SklearnMclBernoulliNBParams",
-            allow_failure="StrictVersion(onnxruntime.__version__)"
-            "<= StrictVersion('0.2.1')",
-        )
+            basename="SklearnMclBernoulliNBParams")
 
-    @unittest.skipIf(not onnx_built_with_ml(),
-                     reason="Requires ONNX-ML extension.")
     def test_model_multinomial_nb_binary_classification_int(self):
         model, X = fit_classification_model(
             MultinomialNB(), 2, is_int=True, pos_features=True)
@@ -194,13 +150,8 @@ class TestNaiveBayesConverter(unittest.TestCase):
             X,
             model,
             model_onnx,
-            basename="SklearnBinMultinomialNBInt-Dec4",
-            allow_failure="StrictVersion(onnxruntime.__version__)"
-            "<= StrictVersion('0.2.1')",
-        )
+            basename="SklearnBinMultinomialNBInt-Dec4")
 
-    @unittest.skipIf(not onnx_built_with_ml(),
-                     reason="Requires ONNX-ML extension.")
     def test_model_multinomial_nb_binary_classification_bool(self):
         model, X = fit_classification_model(
             MultinomialNB(), 2, is_bool=True, pos_features=True)
@@ -215,17 +166,9 @@ class TestNaiveBayesConverter(unittest.TestCase):
             X,
             model,
             model_onnx,
-            basename="SklearnBinMultinomialNBBool-Dec4",
-            allow_failure="StrictVersion(onnxruntime.__version__)"
-            "<= StrictVersion('0.2.1')",
-        )
+            basename="SklearnBinMultinomialNBBool-Dec4")
 
-    @unittest.skipIf(
-        StrictVersion(onnx.__version__) <= StrictVersion("1.3"),
-        reason="Requires opset 9.",
-    )
-    @unittest.skipIf(not onnx_built_with_ml(),
-                     reason="Requires ONNX-ML extension.")
+    @unittest.skipIf(TARGET_OPSET < 9, reason="not available")
     def test_model_bernoulli_nb_binary_classification_int(self):
         model, X = fit_classification_model(
             BernoulliNB(), 2, is_int=True)
@@ -240,17 +183,9 @@ class TestNaiveBayesConverter(unittest.TestCase):
             X,
             model,
             model_onnx,
-            basename="SklearnBinBernoulliNBInt",
-            allow_failure="StrictVersion(onnxruntime.__version__)"
-            "<= StrictVersion('0.2.1')",
-        )
+            basename="SklearnBinBernoulliNBInt")
 
-    @unittest.skipIf(
-        StrictVersion(onnx.__version__) <= StrictVersion("1.3"),
-        reason="Requires opset 9.",
-    )
-    @unittest.skipIf(not onnx_built_with_ml(),
-                     reason="Requires ONNX-ML extension.")
+    @unittest.skipIf(TARGET_OPSET < 9, reason="not available")
     def test_model_bernoulli_nb_binary_classification_bool(self):
         model, X = fit_classification_model(
             BernoulliNB(), 2, is_bool=True)
@@ -265,13 +200,8 @@ class TestNaiveBayesConverter(unittest.TestCase):
             X,
             model,
             model_onnx,
-            basename="SklearnBinBernoulliNBBool",
-            allow_failure="StrictVersion(onnxruntime.__version__)"
-            "<= StrictVersion('0.2.1')",
-        )
+            basename="SklearnBinBernoulliNBBool")
 
-    @unittest.skipIf(not onnx_built_with_ml(),
-                     reason="Requires ONNX-ML extension.")
     def test_model_multinomial_nb_multiclass_int(self):
         model, X = fit_classification_model(
             MultinomialNB(), 5, is_int=True, pos_features=True)
@@ -286,17 +216,9 @@ class TestNaiveBayesConverter(unittest.TestCase):
             X,
             model,
             model_onnx,
-            basename="SklearnMclMultinomialNBInt-Dec4",
-            allow_failure="StrictVersion(onnxruntime.__version__)"
-            "<= StrictVersion('0.2.1')",
-        )
+            basename="SklearnMclMultinomialNBInt-Dec4")
 
-    @unittest.skipIf(
-        StrictVersion(onnx.__version__) <= StrictVersion("1.3"),
-        reason="Requires opset 9.",
-    )
-    @unittest.skipIf(not onnx_built_with_ml(),
-                     reason="Requires ONNX-ML extension.")
+    @unittest.skipIf(TARGET_OPSET < 9, reason="not available")
     def test_model_bernoulli_nb_multiclass_int(self):
         model, X = fit_classification_model(
             BernoulliNB(), 4, is_int=True)
@@ -311,13 +233,8 @@ class TestNaiveBayesConverter(unittest.TestCase):
             X,
             model,
             model_onnx,
-            basename="SklearnMclBernoulliNBInt-Dec4",
-            allow_failure="StrictVersion(onnxruntime.__version__)"
-            "<= StrictVersion('0.2.1')",
-        )
+            basename="SklearnMclBernoulliNBInt-Dec4")
 
-    @unittest.skipIf(not onnx_built_with_ml(),
-                     reason="Requires ONNX-ML extension.")
     def test_model_gaussian_nb_binary_classification(self):
         model, X = fit_classification_model(
             GaussianNB(), 2)
@@ -332,13 +249,8 @@ class TestNaiveBayesConverter(unittest.TestCase):
             X,
             model,
             model_onnx,
-            basename="SklearnBinGaussianNB",
-            allow_failure="StrictVersion(onnxruntime.__version__)"
-            "<= StrictVersion('0.2.1')",
-        )
+            basename="SklearnBinGaussianNB")
 
-    @unittest.skipIf(not onnx_built_with_ml(),
-                     reason="Requires ONNX-ML extension.")
     def test_model_gaussian_nb_multiclass(self):
         model, X = fit_classification_model(
             GaussianNB(), 4)
@@ -353,13 +265,8 @@ class TestNaiveBayesConverter(unittest.TestCase):
             X,
             model,
             model_onnx,
-            basename="SklearnMclGaussianNB",
-            allow_failure="StrictVersion(onnxruntime.__version__)"
-            "<= StrictVersion('0.2.1')",
-        )
+            basename="SklearnMclGaussianNB")
 
-    @unittest.skipIf(not onnx_built_with_ml(),
-                     reason="Requires ONNX-ML extension.")
     def test_model_gaussian_nb_binary_classification_int(self):
         model, X = fit_classification_model(
             GaussianNB(), 2, is_int=True)
@@ -374,13 +281,8 @@ class TestNaiveBayesConverter(unittest.TestCase):
             X,
             model,
             model_onnx,
-            basename="SklearnBinGaussianNBInt",
-            allow_failure="StrictVersion(onnxruntime.__version__)"
-            "<= StrictVersion('0.2.1')",
-        )
+            basename="SklearnBinGaussianNBInt")
 
-    @unittest.skipIf(not onnx_built_with_ml(),
-                     reason="Requires ONNX-ML extension.")
     def test_model_gaussian_nb_multiclass_int(self):
         model, X = fit_classification_model(
             GaussianNB(), 5, is_int=True)
@@ -395,13 +297,8 @@ class TestNaiveBayesConverter(unittest.TestCase):
             X,
             model,
             model_onnx,
-            basename="SklearnMclGaussianNBInt-Dec4",
-            allow_failure="StrictVersion(onnxruntime.__version__)"
-            "<= StrictVersion('0.2.1')",
-        )
+            basename="SklearnMclGaussianNBInt-Dec4")
 
-    @unittest.skipIf(not onnx_built_with_ml(),
-                     reason="Requires ONNX-ML extension.")
     def test_model_gaussian_nb_multiclass_bool(self):
         model, X = fit_classification_model(
             GaussianNB(), 5, is_bool=True)
@@ -416,15 +313,10 @@ class TestNaiveBayesConverter(unittest.TestCase):
             X,
             model,
             model_onnx,
-            basename="SklearnMclGaussianNBBool-Dec4",
-            allow_failure="StrictVersion(onnxruntime.__version__)"
-            "<= StrictVersion('0.2.1')",
-        )
+            basename="SklearnMclGaussianNBBool-Dec4")
 
     @unittest.skipIf(ComplementNB is None,
                      reason="new in scikit version 0.20")
-    @unittest.skipIf(not onnx_built_with_ml(),
-                     reason="Requires ONNX-ML extension.")
     def test_model_complement_nb_binary_classification(self):
         model, X = fit_classification_model(
             ComplementNB(), 2, pos_features=True)
@@ -439,15 +331,10 @@ class TestNaiveBayesConverter(unittest.TestCase):
             X,
             model,
             model_onnx,
-            basename="SklearnBinComplementNB-Dec4",
-            allow_failure="StrictVersion(onnxruntime.__version__)"
-            "<= StrictVersion('0.2.1')",
-        )
+            basename="SklearnBinComplementNB-Dec4")
 
     @unittest.skipIf(ComplementNB is None,
                      reason="new in scikit version 0.20")
-    @unittest.skipIf(not onnx_built_with_ml(),
-                     reason="Requires ONNX-ML extension.")
     def test_model_complement_nb_multiclass(self):
         model, X = fit_classification_model(
             ComplementNB(), 4, pos_features=True)
@@ -462,15 +349,10 @@ class TestNaiveBayesConverter(unittest.TestCase):
             X,
             model,
             model_onnx,
-            basename="SklearnMclComplementNB-Dec4",
-            allow_failure="StrictVersion(onnxruntime.__version__)"
-            "<= StrictVersion('0.2.1')"
-        )
+            basename="SklearnMclComplementNB-Dec4")
 
     @unittest.skipIf(ComplementNB is None,
                      reason="new in scikit version 0.20")
-    @unittest.skipIf(not onnx_built_with_ml(),
-                     reason="Requires ONNX-ML extension.")
     def test_model_complement_nb_binary_classification_int(self):
         model, X = fit_classification_model(
             ComplementNB(), 2, is_int=True, pos_features=True)
@@ -485,15 +367,10 @@ class TestNaiveBayesConverter(unittest.TestCase):
             X,
             model,
             model_onnx,
-            basename="SklearnBinComplementNBInt-Dec4",
-            allow_failure="StrictVersion(onnxruntime.__version__)"
-            "<= StrictVersion('0.2.1')"
-        )
+            basename="SklearnBinComplementNBInt-Dec4")
 
     @unittest.skipIf(ComplementNB is None,
                      reason="new in scikit version 0.20")
-    @unittest.skipIf(not onnx_built_with_ml(),
-                     reason="Requires ONNX-ML extension.")
     def test_model_complement_nb_multiclass_int(self):
         model, X = fit_classification_model(
             ComplementNB(), 5, is_int=True, pos_features=True)
@@ -508,14 +385,10 @@ class TestNaiveBayesConverter(unittest.TestCase):
             X,
             model,
             model_onnx,
-            basename="SklearnMclComplementNBInt-Dec4",
-            allow_failure="StrictVersion(onnxruntime.__version__)"
-            "<= StrictVersion('0.2.1')")
+            basename="SklearnMclComplementNBInt-Dec4")
 
     @unittest.skipIf(ComplementNB is None,
                      reason="new in scikit version 0.20")
-    @unittest.skipIf(not onnx_built_with_ml(),
-                     reason="Requires ONNX-ML extension.")
     def test_model_complement_nb_multiclass_bool(self):
         model, X = fit_classification_model(
             ComplementNB(), 5, is_bool=True, pos_features=True)
@@ -530,14 +403,10 @@ class TestNaiveBayesConverter(unittest.TestCase):
             X,
             model,
             model_onnx,
-            basename="SklearnMclComplementNBBool-Dec4",
-            allow_failure="StrictVersion(onnxruntime.__version__)"
-            "<= StrictVersion('0.2.1')")
+            basename="SklearnMclComplementNBBool-Dec4")
 
     @unittest.skipIf(CategoricalNB is None,
                      reason="new in scikit version 0.22")
-    @unittest.skipIf(not onnx_built_with_ml(),
-                     reason="Requires ONNX-ML extension.")
     def test_model_categorical_nb(self):
         model, X = fit_classification_model(
             CategoricalNB(), 3, is_int=True, pos_features=True)
@@ -552,13 +421,8 @@ class TestNaiveBayesConverter(unittest.TestCase):
             X[10:13],
             model,
             model_onnx,
-            basename="SklearnCategoricalNB",
-            allow_failure="StrictVersion(onnxruntime.__version__)"
-            "<= StrictVersion('0.2.1')",
-        )
+            basename="SklearnCategoricalNB")
 
-    @unittest.skipIf(not onnx_built_with_ml(),
-                     reason="Requires ONNX-ML extension.")
     def test_model_gaussian_nb_multi_class_nocl(self):
         model, X = fit_classification_model(
             GaussianNB(),
@@ -575,11 +439,7 @@ class TestNaiveBayesConverter(unittest.TestCase):
         assert 'cl0' not in sonx
         dump_data_and_model(
             X, model, model_onnx, classes=model.classes_,
-            basename="SklearnGaussianNBMultiNoCl", verbose=False,
-            allow_failure="StrictVersion(onnx.__version__)"
-                          " < StrictVersion('1.2') or "
-                          "StrictVersion(onnxruntime.__version__)"
-                          " <= StrictVersion('0.2.1')")
+            basename="SklearnGaussianNBMultiNoCl")
 
 
 if __name__ == "__main__":
