@@ -1,6 +1,6 @@
 # SPDX-License-Identifier: Apache-2.0
 
-from distutils.version import StrictVersion
+import packaging.version as pv
 import unittest
 import numpy as np
 from numpy.testing import assert_almost_equal
@@ -14,6 +14,7 @@ from sklearn.datasets import make_classification
 from sklearn.model_selection import train_test_split
 from sklearn.ensemble import RandomForestClassifier
 from sklearn.exceptions import ConvergenceWarning
+from sklearn.svm import LinearSVC
 try:
     from sklearn.utils._testing import ignore_warnings
 except ImportError:
@@ -21,8 +22,7 @@ except ImportError:
 from skl2onnx import convert_sklearn
 from skl2onnx.common.data_types import (
     FloatTensorType,
-    Int64TensorType,
-    onnx_built_with_ml)
+    Int64TensorType)
 from test_utils import (
     dump_data_and_model,
     dump_multiple_classification,
@@ -33,23 +33,25 @@ from test_utils import (
 warnings_to_skip = (DeprecationWarning, FutureWarning, ConvergenceWarning)
 
 
+ort_version = '.'.join(ort_version.split('.')[:2])
+
+
 class TestOneVsRestClassifierConverter(unittest.TestCase):
-    @unittest.skipIf(not onnx_built_with_ml(),
-                     reason="Requires ONNX-ML extension.")
+    @unittest.skipIf(True, reason="bug to fix later")
     @ignore_warnings(category=warnings_to_skip)
-    def test_ovr(self):
+    def test_ovr_linear_svc(self):
+        model = OneVsRestClassifier(LinearSVC())
+        dump_multiple_classification(
+            model, target_opset=TARGET_OPSET, verbose=False)
+
+    @ignore_warnings(category=warnings_to_skip)
+    def test_ovr_logistic_regression(self):
         model = OneVsRestClassifier(LogisticRegression())
         dump_multiple_classification(
-            model,
-            allow_failure="StrictVersion(onnxruntime.__version__)"
-                          " <= StrictVersion('0.2.1')",
-            target_opset=TARGET_OPSET
-        )
+            model, target_opset=TARGET_OPSET)
 
-    @unittest.skipIf(not onnx_built_with_ml(),
-                     reason="Requires ONNX-ML extension.")
     @unittest.skipIf(
-        StrictVersion(ort_version) <= StrictVersion('1.4.0'),
+        pv.Version(ort_version) <= pv.Version('1.4.0'),
         reason="onnxruntime too old")
     @ignore_warnings(category=warnings_to_skip)
     def test_ovr_rf(self):
@@ -80,10 +82,8 @@ class TestOneVsRestClassifierConverter(unittest.TestCase):
             # That explains why the test allows less than 3 differences.
             assert_almost_equal(exp_label, got[0])
 
-    @unittest.skipIf(not onnx_built_with_ml(),
-                     reason="Requires ONNX-ML extension.")
     @unittest.skipIf(
-        StrictVersion(ort_version) <= StrictVersion('1.3.0'),
+        pv.Version(ort_version) <= pv.Version('1.3.0'),
         reason="onnxruntime too old")
     @ignore_warnings(category=warnings_to_skip)
     def test_ovr_rf_multilabel_float(self):
@@ -103,10 +103,8 @@ class TestOneVsRestClassifierConverter(unittest.TestCase):
                     X.astype(np.float32), model, model_onnx,
                     basename="SklearnOVRRFMultiLabelFloat%d" % opset)
 
-    @unittest.skipIf(not onnx_built_with_ml(),
-                     reason="Requires ONNX-ML extension.")
     @unittest.skipIf(
-        StrictVersion(ort_version) <= StrictVersion('1.3.0'),
+        pv.Version(ort_version) <= pv.Version('1.3.0'),
         reason="onnxruntime too old")
     @ignore_warnings(category=warnings_to_skip)
     def test_ovr_rf_multilabel_float_11(self):
@@ -127,10 +125,8 @@ class TestOneVsRestClassifierConverter(unittest.TestCase):
                     X.astype(np.float32), model, model_onnx,
                     basename="SklearnOVRRFMultiLabelFloat%d" % opset)
 
-    @unittest.skipIf(not onnx_built_with_ml(),
-                     reason="Requires ONNX-ML extension.")
     @unittest.skipIf(
-        StrictVersion(ort_version) <= StrictVersion('1.3.0'),
+        pv.Version(ort_version) <= pv.Version('1.3.0'),
         reason="onnxruntime too old")
     @ignore_warnings(category=warnings_to_skip)
     def test_ovr_rf_multilabel_int(self):
@@ -150,10 +146,8 @@ class TestOneVsRestClassifierConverter(unittest.TestCase):
                     X.astype(np.int64), model, model_onnx,
                     basename="SklearnOVRRFMultiLabelInt64%d" % opset)
 
-    @unittest.skipIf(not onnx_built_with_ml(),
-                     reason="Requires ONNX-ML extension.")
     @unittest.skipIf(
-        StrictVersion(ort_version) <= StrictVersion('1.3.0'),
+        pv.Version(ort_version) <= pv.Version('1.3.0'),
         reason="onnxruntime too old")
     @ignore_warnings(category=warnings_to_skip)
     def test_ovr_rf_multilabel_int_11(self):
@@ -174,8 +168,6 @@ class TestOneVsRestClassifierConverter(unittest.TestCase):
                     X.astype(np.int64), model, model_onnx,
                     basename="SklearnOVRRFMultiLabelInt64%d" % opset)
 
-    @unittest.skipIf(not onnx_built_with_ml(),
-                     reason="Requires ONNX-ML extension.")
     @ignore_warnings(category=warnings_to_skip)
     def test_ovr_02(self):
         model = OneVsRestClassifier(LogisticRegression())
@@ -183,13 +175,9 @@ class TestOneVsRestClassifierConverter(unittest.TestCase):
             model,
             first_class=2,
             suffix="F2",
-            allow_failure="StrictVersion(onnxruntime.__version__)"
-                          " <= StrictVersion('0.2.1')",
             target_opset=TARGET_OPSET
         )
 
-    @unittest.skipIf(not onnx_built_with_ml(),
-                     reason="Requires ONNX-ML extension.")
     @ignore_warnings(category=warnings_to_skip)
     def test_ovr_string(self):
         model = OneVsRestClassifier(LogisticRegression())
@@ -198,13 +186,9 @@ class TestOneVsRestClassifierConverter(unittest.TestCase):
             verbose=False,
             label_string=True,
             suffix="String",
-            allow_failure="StrictVersion(onnxruntime.__version__)"
-                          " <= StrictVersion('0.2.1')",
             target_opset=TARGET_OPSET
         )
 
-    @unittest.skipIf(not onnx_built_with_ml(),
-                     reason="Requires ONNX-ML extension.")
     @ignore_warnings(category=warnings_to_skip)
     def test_ovr_classification_float(self):
         model, X = fit_classification_model(
@@ -220,13 +204,8 @@ class TestOneVsRestClassifierConverter(unittest.TestCase):
             X,
             model,
             model_onnx,
-            basename="SklearnOVRClassificationFloat",
-            allow_failure="StrictVersion(onnxruntime.__version__)"
-            "<= StrictVersion('0.2.1')",
-        )
+            basename="SklearnOVRClassificationFloat")
 
-    @unittest.skipIf(not onnx_built_with_ml(),
-                     reason="Requires ONNX-ML extension.")
     @ignore_warnings(category=warnings_to_skip)
     def test_ovr_classification_decision_function(self):
         model, X = fit_classification_model(
@@ -245,11 +224,8 @@ class TestOneVsRestClassifierConverter(unittest.TestCase):
             model,
             model_onnx,
             basename="SklearnOVRClassificationDecisionFunction",
-            allow_failure="StrictVersion(onnxruntime.__version__)"
-            "<= StrictVersion('0.2.1')",
-            methods=['predict', 'decision_function'],
-        )
-        if StrictVersion(ort_version) < StrictVersion("1.0.0"):
+            methods=['predict', 'decision_function'])
+        if pv.Version(ort_version) < pv.Version("1.0.0"):
             return
         options = {id(model): {'raw_scores': True, 'zipmap': False}}
         model_onnx = convert_sklearn(
@@ -261,8 +237,6 @@ class TestOneVsRestClassifierConverter(unittest.TestCase):
         dec = model.decision_function(X)
         assert_almost_equal(got, dec, decimal=4)
 
-    @unittest.skipIf(not onnx_built_with_ml(),
-                     reason="Requires ONNX-ML extension.")
     @ignore_warnings(category=warnings_to_skip)
     def test_ovr_classification_decision_function_binary(self):
         model, X = fit_classification_model(
@@ -281,11 +255,8 @@ class TestOneVsRestClassifierConverter(unittest.TestCase):
             model,
             model_onnx,
             basename="SklearnOVRClassificationDecisionFunctionBinary",
-            allow_failure="StrictVersion(onnxruntime.__version__)"
-            "<= StrictVersion('0.2.1')",
-            methods=['predict', 'decision_function_binary'],
-        )
-        if StrictVersion(ort_version) < StrictVersion("1.0.0"):
+            methods=['predict', 'decision_function_binary'])
+        if pv.Version(ort_version) < pv.Version("1.0.0"):
             return
         options = {id(model): {'raw_scores': True, 'zipmap': False}}
         model_onnx = convert_sklearn(
@@ -298,8 +269,6 @@ class TestOneVsRestClassifierConverter(unittest.TestCase):
         assert_almost_equal(got[:, 1], dec, decimal=4)
         assert_almost_equal(-got[:, 0], dec, decimal=4)
 
-    @unittest.skipIf(not onnx_built_with_ml(),
-                     reason="Requires ONNX-ML extension.")
     @ignore_warnings(category=warnings_to_skip)
     def test_ovr_classification_int(self):
         model, X = fit_classification_model(
@@ -315,13 +284,8 @@ class TestOneVsRestClassifierConverter(unittest.TestCase):
             X,
             model,
             model_onnx,
-            basename="SklearnOVRClassificationInt",
-            allow_failure="StrictVersion(onnxruntime.__version__)"
-            "<= StrictVersion('0.2.1')",
-        )
+            basename="SklearnOVRClassificationInt")
 
-    @unittest.skipIf(not onnx_built_with_ml(),
-                     reason="Requires ONNX-ML extension.")
     @ignore_warnings(category=warnings_to_skip)
     def test_ovr_classification_float_binary(self):
         model, X = fit_classification_model(
@@ -337,13 +301,8 @@ class TestOneVsRestClassifierConverter(unittest.TestCase):
             X,
             model,
             model_onnx,
-            basename="SklearnOVRClassificationFloatBin",
-            allow_failure="StrictVersion(onnxruntime.__version__)"
-            "<= StrictVersion('0.2.1')",
-        )
+            basename="SklearnOVRClassificationFloatBin")
 
-    @unittest.skipIf(not onnx_built_with_ml(),
-                     reason="Requires ONNX-ML extension.")
     @ignore_warnings(category=warnings_to_skip)
     def test_ovr_classification_float_binary_nozipmap(self):
         model, X = fit_classification_model(
@@ -356,12 +315,8 @@ class TestOneVsRestClassifierConverter(unittest.TestCase):
         self.assertIsNotNone(model_onnx)
         dump_data_and_model(
             X, model, model_onnx,
-            basename="SklearnOVRClassificationFloatBinNoZipMap",
-            allow_failure="StrictVersion(onnxruntime.__version__)"
-            "<= StrictVersion('0.2.1')")
+            basename="SklearnOVRClassificationFloatBinNoZipMap")
 
-    @unittest.skipIf(not onnx_built_with_ml(),
-                     reason="Requires ONNX-ML extension.")
     @ignore_warnings(category=warnings_to_skip)
     def test_ovr_classification_int_binary(self):
         model, X = fit_classification_model(
@@ -377,13 +332,8 @@ class TestOneVsRestClassifierConverter(unittest.TestCase):
             X,
             model,
             model_onnx,
-            basename="SklearnOVRClassificationIntBin",
-            allow_failure="StrictVersion(onnxruntime.__version__)"
-            "<= StrictVersion('0.2.1')",
-        )
+            basename="SklearnOVRClassificationIntBin")
 
-    @unittest.skipIf(not onnx_built_with_ml(),
-                     reason="Requires ONNX-ML extension.")
     @ignore_warnings(category=warnings_to_skip)
     def test_ovr_classification_float_mlp(self):
         model, X = fit_classification_model(
@@ -399,13 +349,8 @@ class TestOneVsRestClassifierConverter(unittest.TestCase):
             X,
             model,
             model_onnx,
-            basename="SklearnOVRClassificationFloatMLP",
-            allow_failure="StrictVersion(onnxruntime.__version__)"
-            "<= StrictVersion('0.2.1')",
-        )
+            basename="SklearnOVRClassificationFloatMLP")
 
-    @unittest.skipIf(not onnx_built_with_ml(),
-                     reason="Requires ONNX-ML extension.")
     @ignore_warnings(category=warnings_to_skip)
     def test_ovr_classification_int_ensemble(self):
         model, X = fit_classification_model(
@@ -421,13 +366,8 @@ class TestOneVsRestClassifierConverter(unittest.TestCase):
             X,
             model,
             model_onnx,
-            basename="SklearnOVRClassificationIntEnsemble",
-            allow_failure="StrictVersion(onnxruntime.__version__)"
-            "<= StrictVersion('0.2.1')",
-        )
+            basename="SklearnOVRClassificationIntEnsemble")
 
-    @unittest.skipIf(not onnx_built_with_ml(),
-                     reason="Requires ONNX-ML extension.")
     @ignore_warnings(category=warnings_to_skip)
     def test_ovr_classification_float_binary_ensemble(self):
         model, X = fit_classification_model(
@@ -443,13 +383,8 @@ class TestOneVsRestClassifierConverter(unittest.TestCase):
             X,
             model,
             model_onnx,
-            basename="SklearnOVRClassificationFloatBinEnsemble",
-            allow_failure="StrictVersion(onnxruntime.__version__)"
-            "<= StrictVersion('0.2.1')",
-        )
+            basename="SklearnOVRClassificationFloatBinEnsemble")
 
-    @unittest.skipIf(not onnx_built_with_ml(),
-                     reason="Requires ONNX-ML extension.")
     @ignore_warnings(category=warnings_to_skip)
     def test_ovr_classification_int_binary_mlp(self):
         model, X = fit_classification_model(
@@ -465,13 +400,8 @@ class TestOneVsRestClassifierConverter(unittest.TestCase):
             X,
             model,
             model_onnx,
-            basename="SklearnOVRClassificationIntBinMLP",
-            allow_failure="StrictVersion(onnxruntime.__version__)"
-            "<= StrictVersion('0.2.1')",
-        )
+            basename="SklearnOVRClassificationIntBinMLP")
 
-    @unittest.skipIf(not onnx_built_with_ml(),
-                     reason="Requires ONNX-ML extension.")
     @ignore_warnings(category=warnings_to_skip)
     def test_ovr_regression_float(self):
         """The test is unstable, some observations
@@ -493,13 +423,8 @@ class TestOneVsRestClassifierConverter(unittest.TestCase):
             X[:5],
             model,
             model_onnx,
-            basename="SklearnOVRRegressionFloat-Out0",
-            allow_failure="StrictVersion(onnxruntime.__version__)"
-            "<= StrictVersion('0.2.1')",
-        )
+            basename="SklearnOVRRegressionFloat-Out0")
 
-    @unittest.skipIf(not onnx_built_with_ml(),
-                     reason="Requires ONNX-ML extension.")
     @ignore_warnings(category=warnings_to_skip)
     def test_ovr_regression_int(self):
         model, X = fit_classification_model(
@@ -515,13 +440,8 @@ class TestOneVsRestClassifierConverter(unittest.TestCase):
             X,
             model,
             model_onnx,
-            basename="SklearnOVRRegressionInt-Out0",
-            allow_failure="StrictVersion(onnxruntime.__version__)"
-            "<= StrictVersion('0.2.1')",
-        )
+            basename="SklearnOVRRegressionInt-Out0")
 
-    @unittest.skipIf(not onnx_built_with_ml(),
-                     reason="Requires ONNX-ML extension.")
     @ignore_warnings(category=warnings_to_skip)
     def test_ovr_regression_float_mlp(self):
         model, X = fit_classification_model(
@@ -537,13 +457,8 @@ class TestOneVsRestClassifierConverter(unittest.TestCase):
             X,
             model,
             model_onnx,
-            basename="SklearnOVRRegressionFloatMLP-Out0",
-            allow_failure="StrictVersion(onnxruntime.__version__)"
-            "<= StrictVersion('0.2.1')",
-        )
+            basename="SklearnOVRRegressionFloatMLP-Out0")
 
-    @unittest.skipIf(not onnx_built_with_ml(),
-                     reason="Requires ONNX-ML extension.")
     @ignore_warnings(category=warnings_to_skip)
     def test_ovr_regression_int_ensemble(self):
         model, X = fit_classification_model(
@@ -559,13 +474,9 @@ class TestOneVsRestClassifierConverter(unittest.TestCase):
             X,
             model,
             model_onnx,
-            basename="SklearnOVRRegressionIntEnsemble-Out0",
-            allow_failure="StrictVersion(onnxruntime.__version__)"
-            "<= StrictVersion('0.2.1')")
+            basename="SklearnOVRRegressionIntEnsemble-Out0")
 
-    @unittest.skipIf(not onnx_built_with_ml(),
-                     reason="Requires ONNX-ML extension.")
-    @unittest.skipIf(StrictVersion(ort_version) < StrictVersion("1.2.0"),
+    @unittest.skipIf(pv.Version(ort_version) < pv.Version("1.2.0"),
                      reason="fails to load the model")
     def test_ovr_raw_scores(self):
         X, y = make_classification(
@@ -592,4 +503,5 @@ class TestOneVsRestClassifierConverter(unittest.TestCase):
 
 
 if __name__ == "__main__":
+    # TestOneVsRestClassifierConverter().test_ovr_linear_svc()
     unittest.main()
