@@ -4,16 +4,30 @@
 Tests scikit-learn's standard scaler converter.
 """
 import unittest
+import packaging.version as pv
 import numpy
+from onnxruntime import __version__ as ort_version
 from sklearn.preprocessing import (
     StandardScaler, RobustScaler, MinMaxScaler, MaxAbsScaler)
+try:
+    # scikit-learn >= 0.22
+    from sklearn.utils._testing import ignore_warnings
+except ImportError:
+    # scikit-learn < 0.22
+    from sklearn.utils.testing import ignore_warnings
 from skl2onnx import convert_sklearn
-from skl2onnx.common.data_types import Int64TensorType, FloatTensorType
+from skl2onnx.common.data_types import (
+    Int64TensorType, FloatTensorType, DoubleTensorType)
 from test_utils import dump_data_and_model, TARGET_OPSET
 
 
+ort_version = ".".join(ort_version.split('.')[:2])
+
+
 class TestSklearnScalerConverter(unittest.TestCase):
-    def test_standard_scaler(self):
+
+    @ignore_warnings(category=DeprecationWarning)
+    def test_standard_scaler_int(self):
         model = StandardScaler()
         data = [[0, 0, 3], [1, 1, 0], [0, 2, 1], [1, 0, 2]]
         model.fit(data)
@@ -26,6 +40,35 @@ class TestSklearnScalerConverter(unittest.TestCase):
             model, model_onnx,
             basename="SklearnStandardScalerInt64")
 
+    @ignore_warnings(category=DeprecationWarning)
+    def test_min_max_scaler_int(self):
+        model = MinMaxScaler()
+        data = [[0, 0, 3], [1, 1, 0], [0, 2, 1], [1, 0, 2]]
+        model.fit(data)
+        model_onnx = convert_sklearn(model, "scaler",
+                                     [("input", Int64TensorType([None, 3]))],
+                                     target_opset=TARGET_OPSET)
+        self.assertTrue(model_onnx is not None)
+        dump_data_and_model(
+            numpy.array(data, dtype=numpy.int64),
+            model, model_onnx,
+            basename="SklearnMinMaxScalerInt64")
+
+    @ignore_warnings(category=DeprecationWarning)
+    def test_standard_scaler_double(self):
+        model = StandardScaler()
+        data = [[0, 0, 3], [1, 1, 0], [0, 2, 1], [1, 0, 2]]
+        model.fit(data)
+        model_onnx = convert_sklearn(model, "scaler",
+                                     [("input", DoubleTensorType([None, 3]))],
+                                     target_opset=TARGET_OPSET)
+        self.assertTrue(model_onnx is not None)
+        dump_data_and_model(
+            numpy.array(data, dtype=numpy.float64),
+            model, model_onnx,
+            basename="SklearnStandardScalerDouble")
+
+    @ignore_warnings(category=DeprecationWarning)
     def test_standard_scaler_blacklist(self):
         model = StandardScaler()
         data = numpy.array([[0, 0, 3], [1, 1, 0], [0, 2, 1], [1, 0, 2]],
@@ -41,6 +84,7 @@ class TestSklearnScalerConverter(unittest.TestCase):
             data, model, model_onnx,
             basename="SklearnStandardScalerBlackList")
 
+    @ignore_warnings(category=DeprecationWarning)
     def test_standard_scaler_floats(self):
         model = StandardScaler()
         data = [
@@ -58,6 +102,7 @@ class TestSklearnScalerConverter(unittest.TestCase):
             numpy.array(data, dtype=numpy.float32),
             model, basename="SklearnStandardScalerFloat32")
 
+    @ignore_warnings(category=DeprecationWarning)
     def test_standard_scaler_floats_div(self):
         model = StandardScaler()
         data = [
@@ -76,6 +121,7 @@ class TestSklearnScalerConverter(unittest.TestCase):
             numpy.array(data, dtype=numpy.float32),
             model, basename="SklearnStandardScalerFloat32Div")
 
+    @ignore_warnings(category=DeprecationWarning)
     def test_standard_scaler_floats_div_cast(self):
         model = StandardScaler()
         data = [
@@ -97,6 +143,7 @@ class TestSklearnScalerConverter(unittest.TestCase):
             numpy.array(data, dtype=numpy.float32),
             model, basename="SklearnStandardScalerFloat32DivCast")
 
+    @ignore_warnings(category=DeprecationWarning)
     def test_standard_scaler_floats_no_std(self):
         model = StandardScaler(with_std=False)
         data = [
@@ -114,6 +161,7 @@ class TestSklearnScalerConverter(unittest.TestCase):
             numpy.array(data, dtype=numpy.float32),
             model, basename="SklearnStandardScalerFloat32NoStd")
 
+    @ignore_warnings(category=DeprecationWarning)
     def test_standard_scaler_floats_no_mean(self):
         model = StandardScaler(with_mean=False)
         data = [
@@ -131,6 +179,7 @@ class TestSklearnScalerConverter(unittest.TestCase):
             numpy.array(data, dtype=numpy.float32),
             model, basename="SklearnStandardScalerFloat32NoMean")
 
+    @ignore_warnings(category=DeprecationWarning)
     def test_standard_scaler_floats_no_mean_std(self):
         model = StandardScaler(with_mean=False, with_std=False)
         data = [
@@ -148,6 +197,7 @@ class TestSklearnScalerConverter(unittest.TestCase):
             numpy.array(data, dtype=numpy.float32),
             model, basename="SklearnStandardScalerFloat32NoMeanStd")
 
+    @ignore_warnings(category=DeprecationWarning)
     def test_robust_scaler_floats(self):
         model = RobustScaler()
         data = [
@@ -165,6 +215,25 @@ class TestSklearnScalerConverter(unittest.TestCase):
             numpy.array(data, dtype=numpy.float32),
             model, basename="SklearnRobustScalerFloat32")
 
+    @ignore_warnings(category=DeprecationWarning)
+    def test_robust_scaler_doubles(self):
+        model = RobustScaler()
+        data = [
+            [0.0, 0.0, 3.0],
+            [1.0, 1.0, 0.0],
+            [0.0, 2.0, 1.0],
+            [1.0, 0.0, 2.0],
+        ]
+        model.fit(data)
+        model_onnx = convert_sklearn(model, "scaler",
+                                     [("input", DoubleTensorType([None, 3]))],
+                                     target_opset=TARGET_OPSET)
+        self.assertTrue(model_onnx is not None)
+        dump_data_and_model(
+            numpy.array(data, dtype=numpy.float64),
+            model, model_onnx, basename="SklearnRobustScalerFloat64")
+
+    @ignore_warnings(category=DeprecationWarning)
     def test_robust_scaler_floats_no_bias(self):
         model = RobustScaler(with_centering=False)
         data = [
@@ -183,6 +252,7 @@ class TestSklearnScalerConverter(unittest.TestCase):
             model,
             basename="SklearnRobustScalerWithCenteringFloat32")
 
+    @ignore_warnings(category=DeprecationWarning)
     def test_robust_scaler_floats_no_scaling(self):
         model = RobustScaler(with_scaling=False)
         data = [
@@ -200,6 +270,7 @@ class TestSklearnScalerConverter(unittest.TestCase):
             numpy.array(data, dtype=numpy.float32),
             model, basename="SklearnRobustScalerNoScalingFloat32")
 
+    @ignore_warnings(category=DeprecationWarning)
     def test_robust_scaler_floats_no_centering_scaling(self):
         model = RobustScaler(with_centering=False, with_scaling=False)
         data = [
@@ -218,6 +289,7 @@ class TestSklearnScalerConverter(unittest.TestCase):
             model,
             basename="SklearnRobustScalerNoCenteringScalingFloat32")
 
+    @ignore_warnings(category=DeprecationWarning)
     def test_min_max_scaler(self):
         model = MinMaxScaler()
         data = [
@@ -235,10 +307,71 @@ class TestSklearnScalerConverter(unittest.TestCase):
             numpy.array(data, dtype=numpy.float32),
             model, basename="SklearnMinMaxScaler")
 
+    @ignore_warnings(category=DeprecationWarning)
+    def test_min_max_scaler_double(self):
+        model = MinMaxScaler()
+        data = [
+            [0.0, 0.0, 3.0],
+            [1.0, 1.0, 0.0],
+            [0.0, 2.0, 1.0],
+            [1.0, 0.0, 2.0],
+        ]
+        model.fit(data)
+        model_onnx = convert_sklearn(model, "scaler",
+                                     [("input", DoubleTensorType([None, 3]))],
+                                     target_opset=TARGET_OPSET)
+        self.assertTrue(model_onnx is not None)
+        dump_data_and_model(
+            numpy.array(data, dtype=numpy.float64),
+            model, model_onnx, basename="SklearnMinMaxScalerDouble")
+
+    @ignore_warnings(category=DeprecationWarning)
+    @unittest.skipIf(pv.Version(ort_version) < pv.Version("1.9.0"),
+                     reason="Operator clip not fully implemented")
+    def test_min_max_scaler_clip(self):
+        model = MinMaxScaler(clip=True)
+        data = [
+            [0.0, 0.0, 3.0],
+            [1.0, 1.0, 0.0],
+            [0.0, 2.0, 1.0],
+            [1.0, 0.0, 2.0],
+        ]
+        model.fit(data)
+        model_onnx = convert_sklearn(model, "scaler",
+                                     [("input", FloatTensorType([None, 3]))],
+                                     target_opset=TARGET_OPSET)
+        self.assertTrue(model_onnx is not None)
+        data[0][0] = 1e6
+        dump_data_and_model(
+            numpy.array(data, dtype=numpy.float32),
+            model, model_onnx, basename="SklearnMinMaxScalerClip")
+
+    @ignore_warnings(category=DeprecationWarning)
+    @unittest.skipIf(pv.Version(ort_version) < pv.Version("1.9.0"),
+                     reason="Operator clip not fully implemented")
+    def test_min_max_scaler_double_clip(self):
+        model = MinMaxScaler(clip=True)
+        data = [
+            [0.0, 0.0, 3.0],
+            [1.0, 1.0, 0.0],
+            [0.0, 2.0, 1.0],
+            [1.0, 0.0, 2.0],
+        ]
+        model.fit(data)
+        model_onnx = convert_sklearn(model, "scaler",
+                                     [("input", DoubleTensorType([None, 3]))],
+                                     target_opset=TARGET_OPSET)
+        self.assertTrue(model_onnx is not None)
+        data[0][0] = 1e6
+        dump_data_and_model(
+            numpy.array(data, dtype=numpy.float64),
+            model, model_onnx, basename="SklearnMinMaxScalerDouble")
+
+    @ignore_warnings(category=DeprecationWarning)
     def test_max_abs_scaler(self):
         model = MaxAbsScaler()
         data = [
-            [0.0, 0.0, 3.0],
+            [0.0, 0.0, -3.0],
             [1.0, 1.0, 0.0],
             [0.0, 2.0, 1.0],
             [1.0, 0.0, 2.0],
@@ -252,6 +385,24 @@ class TestSklearnScalerConverter(unittest.TestCase):
             numpy.array(data, dtype=numpy.float32),
             model, basename="SklearnMaxAbsScaler")
 
+    @ignore_warnings(category=DeprecationWarning)
+    def test_max_abs_scaler_double(self):
+        model = MaxAbsScaler()
+        data = [
+            [0.0, 0.0, -3.0],
+            [1.0, 1.0, 0.0],
+            [0.0, 2.0, 1.0],
+            [1.0, 0.0, 2.0],
+        ]
+        model.fit(data)
+        model_onnx = convert_sklearn(model, "scaler",
+                                     [("input", DoubleTensorType([None, 3]))],
+                                     target_opset=TARGET_OPSET)
+        self.assertTrue(model_onnx is not None)
+        dump_data_and_model(
+            numpy.array(data, dtype=numpy.float64),
+            model, model_onnx, basename="SklearnMaxAbsScalerDouble")
+
 
 if __name__ == "__main__":
     unittest.main()
